@@ -10,11 +10,12 @@ matplotlib.use('TkAgg')
 import matplotlib.pyplot as plt
 import scipy.io
 
-from freq_response import *
-from dataloader_gui import Individual_Dataset
-from evaluation import *
+from .freq_response import *
+from .dataloader_gui import Individual_Dataset
 import variable
 import scheme_var
+from .train_test import Test, Scheme
+
 
 #====================== Main========================
 #--------------------------Control Center----------------------------------
